@@ -16,25 +16,31 @@ mx_crosscheck <- function() {
   internet_check()
   mx_info()
 
-  # Get number of unique records in the medRxiv archive ---------------------
-
+  # Get number of unique records in the medRxiv archive
   base_link <- api_link("medrxiv", "2019-01-01", as.character(Sys.Date()), "0")
-
   details <- api_to_df(base_link)
 
-  reference <- details$messages[1, 6]
+  # Ensure 'reference' is numeric
+  reference <- as.numeric(details$messages[1, 6])
+  if (is.na(reference)) {
+    stop("Reference value is not numeric.")
+  }
 
-  # Get number of unique records extracted ----------------------------------
+  # Get number of unique records extracted
   data <- suppressMessages(mx_search(mx_snapshot(),
     query = "*",
     deduplicate = FALSE
   ))
 
-  extracted <- nrow(data)
+  # Ensure 'extracted' is numeric
+  extracted <- as.numeric(nrow(data))
+  if (is.na(extracted)) {
+    stop("Extracted value is not numeric.")
+  }
 
   diff <- reference - extracted
 
-  if (identical(reference, extracted) == TRUE) {
+  if (identical(reference, extracted)) {
     message("No records added/updated since last snapshot.") # nocov
   } else {
     message(paste0(
